<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Proposar</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Trobades</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Gran</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Perdudes</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Éxit</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Final del joc</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 de %n punt</numerusform>
            <numerusform>%1 de %n punts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 de %n punt</numerusform>
            <numerusform>3 de %n punts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 de %n punt</numerusform>
            <numerusform>2 de %n punts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 de %n punt</numerusform>
            <numerusform>1 de %n punts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 de %n punt</numerusform>
            <numerusform>0 de %n punts</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punt</numerusform>
            <numerusform>%n punts</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>La puntuación máxima se calcula a partir de los siguientes treinta palabras:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n sugeriment</numerusform>
            <numerusform>%n sugeriments</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n encert</numerusform>
            <numerusform>%n encerts</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Clàssic</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Emplenar</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Resistència</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Ratllar</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Assignació</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplina</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Compte enrrera de 30 segons i incrementa amb els encerts.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Compte enrrera de 3 minuts.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Compte enrrera de 30 segons i incrementa amb els encerts.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Compte enrrera de 45 segons i s&apos;atura amb els encerts.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>El joc acaba després de tres errors.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>El joc acaba després de 30 intents.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Compte enrrera de 30 segons i incrementa o disminueix amb els intents.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>No és possible llegir el tauler de lletres del fitxer.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>No és possible llegir el llistat de paraules del fitxer.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Idioma del panell</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalitzat</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Seleccionar ...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Els canvis seran efectius en començar una nova partida.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Tauler de lletres:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Llista de paraules:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Diccionari:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Elegiu el fitxer de tauler de lletres</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Escolliu un fitxer de paraules</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccionau l&apos;idioma del programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Si us plau, reinicieu el programa per a què es faci efectiu el canvi d&apos;idioma.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Joc nou</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Nombre de paraules:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Longitud mínima de paraula:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baix</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mitjà</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatori</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n lletra</numerusform>
            <numerusform>%n lletres</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Puntuacions més altes</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Puntuació</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pausa&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click per a continuar la partida.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Si us plau, espereu&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Carregant el joc...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Clicau per a començar una nova partida.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Si us plau, espereu&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generant un nou taulell...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Si us plau, espereu&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimitzant el llistat de paraules...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Joc</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Nou &amp;Joc...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Nou Tauler</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolliu...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Compartiu...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Fi</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalls</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Puntuaciones més altes</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Surt</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Preferències</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Mostrar &amp;Puntuació Màxima</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Mai</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Final del joc</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Sempre</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Mostrar paraules &amp;perdudes</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Mostrar &amp;Recompte de paraules</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Idioma del &amp;tauler...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma del programa...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controls</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Crèdits</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Crèdits de &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Crèdits</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Una variant de &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; individual</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribuït sota llicència &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Llista de paraules anglesas basada en &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; de Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Llista de paraules hebrea basada en &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El i Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importar Joc</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Jocs Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>No és possible iniciar el joc sol·licitat.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Exportar Joc</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Finalizar el joc actual?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Mida del tauler:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Gran</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Densitat de paraules:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Longitud de les paraules:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 o més lletres</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Tipus de joc:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripció:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controls</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Jugar amb el ratolí:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una paraula:&lt;/b&gt; Clica sobre les lletres d&apos;una paraula.&lt;br&gt;&lt;b&gt;Fes un suggeriment:&lt;/b&gt; Clica sobre la darrera lletra seleccionada.&lt;br&gt;&lt;b&gt;Borrar lletres:&lt;/b&gt; Clica sobre una lletra seleccionada prèviament.&lt;br&gt;&lt;b&gt;Borrar la paraula:&lt;/b&gt; Clica dues vegades sobre la primera lletra seleccionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Jugar amb el teclat:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una paraula:&lt;/b&gt; Tecleja les lletres d&apos;una paraula.&lt;br&gt;&lt;b&gt;Fes una suggerencia:&lt;/b&gt; Presiona Enter.&lt;br&gt;&lt;b&gt;Borra la paraula:&lt;/b&gt; Presiona Ctrl+Espai.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Lletres:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Trobades:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punt</numerusform>
            <numerusform>%n punts</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Joc de cerca de paraules</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Un fitxer de joc per jugar.</translation>
    </message>
</context>
</TS>
